@@ -22,4 +22,10 @@ NULL
 #' @name %>%
 #' @export
 #' @rdname billboarder-exports
+NULL
+
+#' @importFrom htmlwidgets JS
+#' @name JS
+#' @export
+#' @rdname billboarder-exports
 NULL
\ No newline at end of file
